You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by ac...@apache.org on 2019/08/06 09:49:59 UTC

[camel] 11/20: CAMEL-13792 - Rename components to default names, Camel-quartz2 to camel-quartz - Fixed references in itest OSGI

This is an automated email from the ASF dual-hosted git repository.

acosentino pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git

commit c047566dd28c5348404aaff1cb472f356945f0a1
Author: Andrea Cosentino <an...@gmail.com>
AuthorDate: Tue Aug 6 10:55:10 2019 +0200

    CAMEL-13792 - Rename components to default names, Camel-quartz2 to camel-quartz - Fixed references in itest OSGI
---
 platforms/spring-boot/components-starter/README.adoc         |  1 -
 ...artz2JmxUpdateTest.java => CamelQuartzJmxUpdateTest.java} | 12 ++++++------
 .../org/apache/camel/itest/CamelQuartz2JmxUpdateTest.xml     |  2 +-
 3 files changed, 7 insertions(+), 8 deletions(-)

diff --git a/platforms/spring-boot/components-starter/README.adoc b/platforms/spring-boot/components-starter/README.adoc
index f8db999..d0ee29b 100644
--- a/platforms/spring-boot/components-starter/README.adoc
+++ b/platforms/spring-boot/components-starter/README.adoc
@@ -20,7 +20,6 @@ The following components do not have a starter because of compatibility issues:
 * **camel-eventadmin** (intended for OSGi only)
 * **camel-ibatis** (`camel-mybatis-starter` is included)
 * **camel-paxlogging** (intended for OSGi only)
-* **camel-quartz** (`camel-quartz2-starter` is included)
 * **camel-scala**
 * **camel-scr** (intended for OSGi only)
 * **camel-spark-rest**
diff --git a/tests/camel-itest-osgi/src/test/resources/org/apache/camel/itest/CamelQuartz2JmxUpdateTest.xml b/tests/camel-itest-osgi/src/test/resources/org/apache/camel/itest/CamelQuartz2JmxUpdateTest.xml
index 920b2cc..6eb956e 100644
--- a/tests/camel-itest-osgi/src/test/resources/org/apache/camel/itest/CamelQuartz2JmxUpdateTest.xml
+++ b/tests/camel-itest-osgi/src/test/resources/org/apache/camel/itest/CamelQuartz2JmxUpdateTest.xml
@@ -24,7 +24,7 @@
 
   <camelContext id="myCamel" xmlns="http://camel.apache.org/schema/blueprint">
     <route>
-      <from uri="quartz2://myGroup/myTimer?cron=0/1 * * * * ?" />
+      <from uri="quartz://myGroup/myTimer?cron=0/1 * * * * ?" />
       <transform>
         <constant>Hello World</constant>
       </transform>
diff --git a/tests/camel-itest-osgi/src/test/java/org/apache/camel/itest/CamelQuartz2JmxUpdateTest.java b/tests/camel-itest-osgi/src/test/java/org/apache/camel/itest/CamelQuartzJmxUpdateTest.java
similarity index 95%
rename from tests/camel-itest-osgi/src/test/java/org/apache/camel/itest/CamelQuartz2JmxUpdateTest.java
rename to tests/camel-itest-osgi/src/test/java/org/apache/camel/itest/CamelQuartzJmxUpdateTest.java
index 0a308c0..b4a9389 100644
--- a/tests/camel-itest-osgi/src/test/java/org/apache/camel/itest/CamelQuartz2JmxUpdateTest.java
+++ b/tests/camel-itest-osgi/src/test/java/org/apache/camel/itest/CamelQuartzJmxUpdateTest.java
@@ -48,19 +48,19 @@ import static org.junit.Assert.assertNotEquals;
  * CAMEL-11471: Unable to update the cron details from Quartz scheduler MBean
  */
 @RunWith(PaxExam.class)
-public class CamelQuartz2JmxUpdateTest extends AbstractFeatureTest {
+public class CamelQuartzJmxUpdateTest extends AbstractFeatureTest {
 
-    private static final Logger LOGGER = LoggerFactory.getLogger(CamelQuartz2JmxUpdateTest.class);
+    private static final Logger LOGGER = LoggerFactory.getLogger(CamelQuartzJmxUpdateTest.class);
 
     @Test
     public void testUpdateCronDetails() throws Exception {
-        // install camel-quartz2 here as 'wrap:' is not available at boot time
-        installCamelFeature("camel-quartz2");
+        // install camel-quartz here as 'wrap:' is not available at boot time
+        installCamelFeature("camel-quartz");
 
         // install the camel blueprint xml file we use in this test
         URL url = ObjectHelper.loadResourceAsURL("org/apache/camel/itest/CamelQuartz2JmxUpdateTest.xml",
-            CamelQuartz2JmxUpdateTest.class.getClassLoader());
-        installBlueprintAsBundle("CamelQuartz2JmxUpdateTest", url, true);
+            CamelQuartzJmxUpdateTest.class.getClassLoader());
+        installBlueprintAsBundle("CamelQuartzJmxUpdateTest", url, true);
 
         // lookup Camel from OSGi
         CamelContext camel = getOsgiService(bundleContext, CamelContext.class);